"use strict";Object.defineProperty(exports, "__esModule", {value: true});// src/common/data/day.ts
var DAY_MS = 864e5;
function dayYear(day) {
  return Math.floor(day / 1e4);
}
function dayMonth(day) {
  return Math.floor(day / 100 % 100);
}
function dayDay(day) {
  return Math.floor(day % 100);
}
function dayToParts(day) {
  return [dayYear(day), dayMonth(day), dayDay(day)];
}
function dayToDate(day, utc = false) {
  return utc ? /* @__PURE__ */ new Date(`${dayToString(day)}T00:00:00.000Z`) : new Date(
    day / 1e4,
    // year
    day / 100 % 100 - 1,
    // month
    day % 100
    // day
  );
}
function dayFromToday() {
  return dayFromDate(/* @__PURE__ */ new Date());
}
function dayFromAny(value, utc = false) {
  if (typeof value === "number") {
    if (value < 100)
      return;
    return value;
  } else if (typeof value === "string") {
    return dayFromString(value);
  } else if (Array.isArray(value) && value.length === 3) {
    const [year, month, day] = value;
    return dayFromParts(year, month, day);
  } else if (value instanceof Date) {
    return dayFromDate(value, utc);
  }
}
function dayToDateUTC(day) {
  return dayToDate(day, true);
}
function dayToDateGMT(day) {
  return dayToDate(day, true);
}
function dayFromDate(date, utc = false) {
  return utc ? dayFromString(date.toISOString()) : date.getFullYear() * 1e4 + (date.getMonth() + 1) * 100 + date.getDate();
}
function dayFromDateUTC(date) {
  return dayFromDate(date, true);
}
function dayFromDateGMT(date) {
  return dayFromDate(date, true);
}
function dayToTimestamp(day, utc = true) {
  return dayToDate(day, utc).getTime();
}
function dayFromTimestamp(ms, utc = true) {
  return dayFromDate(new Date(ms), utc);
}
function dayToString(day, sep = "-") {
  const baseString = String(day);
  return baseString.slice(0, 4) + sep + baseString.slice(4, 6) + sep + baseString.slice(6, 8);
}
function dayFromParts(year, month = 1, day = 1) {
  if (month < 1 || month > 12 || day < 1 || day > 31)
    return;
  return year * 1e4 + month * 100 + day;
}
function dayFromString(value) {
  const string = String(value).replace(/\D/g, "").slice(0, 8);
  if (string.length === 8)
    return +string;
}
function dayMonthStart(day, offset = 0) {
  let year = dayYear(day);
  let month = dayMonth(day);
  if (offset !== 0) {
    month += offset;
    year += Math.floor((month - 1) / 12);
    month = Math.floor((month - 1) % 12) + 1;
    if (month === 0)
      month = 12;
  }
  return dayFromParts(year, month, 1);
}
function dayYearStart(day, offset = 0) {
  const year = dayYear(day);
  return dayFromParts(year + offset, 1, 1);
}
function dayOffset(day, offset) {
  return dayFromTimestamp(dayToTimestamp(day) + offset * DAY_MS);
}
function dayDiff(left, right) {
  return Math.round((dayToTimestamp(right) - dayToTimestamp(left)) / DAY_MS);
}
function dayRange(left, right) {
  const list = [];
  if (right == null)
    right = dayFromToday();
  if (left < 0)
    left = dayOffset(right, left + 1);
  while (left <= right) {
    list.push(left);
    left = dayOffset(left, 1);
  }
  return list;
}
function* dayIterator(left, right) {
  const list = [];
  if (right == null)
    right = dayFromToday();
  if (left < 0)
    left = dayOffset(right, left + 1);
  while (left <= right) {
    yield left;
    left = dayOffset(left, 1);
  }
  return list;
}


























exports.DAY_MS = DAY_MS; exports.dayYear = dayYear; exports.dayMonth = dayMonth; exports.dayDay = dayDay; exports.dayToParts = dayToParts; exports.dayToDate = dayToDate; exports.dayFromToday = dayFromToday; exports.dayFromAny = dayFromAny; exports.dayToDateUTC = dayToDateUTC; exports.dayToDateGMT = dayToDateGMT; exports.dayFromDate = dayFromDate; exports.dayFromDateUTC = dayFromDateUTC; exports.dayFromDateGMT = dayFromDateGMT; exports.dayToTimestamp = dayToTimestamp; exports.dayFromTimestamp = dayFromTimestamp; exports.dayToString = dayToString; exports.dayFromParts = dayFromParts; exports.dayFromString = dayFromString; exports.dayMonthStart = dayMonthStart; exports.dayYearStart = dayYearStart; exports.dayOffset = dayOffset; exports.dayDiff = dayDiff; exports.dayRange = dayRange; exports.dayIterator = dayIterator;
//# sourceMappingURL=chunk-B3U4FDQH.cjs.map