import {
  isHiddenPath
} from "./chunk-QU4LUB3H.js";
import {
  globToRegExp
} from "./chunk-EGXUCKU4.js";

// src/node/files-async.ts
import { readdir, stat } from "node:fs/promises";
import { join, resolve } from "node:path";
import process from "node:process";
async function getStatAsync(path) {
  try {
    return await stat(path);
  } catch (err) {
  }
}
async function getFingerprintAsync(path) {
  const stat2 = await getStatAsync(path);
  if (stat2 == null)
    return;
  const { mtimeMs, size } = stat2;
  return `${path}|${mtimeMs}|${size}`;
}
async function walkSyncAsync(rootFolder, subFolder = "", ignoreHidden = true) {
  let resultPaths = [];
  const paths = await readdir(resolve(rootFolder, subFolder));
  if (paths != null && paths.length > 0) {
    for (let file of paths) {
      file = join(subFolder, file);
      if (ignoreHidden && isHiddenPath(file))
        continue;
      const realFile = join(rootFolder, file);
      const stat2 = await getStatAsync(realFile);
      if (stat2 && stat2.isDirectory())
        resultPaths = resultPaths.concat(await walkSyncAsync(rootFolder, file) || []);
      else
        resultPaths.push(file);
    }
  }
  return resultPaths;
}
async function filesAsync(opt = {}) {
  let {
    pattern,
    filter,
    basePath = process.cwd(),
    ignoreHidden = false
  } = opt;
  let paths = await walkSyncAsync(basePath, "", ignoreHidden);
  paths = paths.filter(
    (path) => !(ignoreHidden && (path.startsWith(".") || path.includes("/.")))
  );
  if (pattern) {
    if (typeof pattern === "string")
      pattern = globToRegExp(pattern);
    if (pattern instanceof RegExp) {
      const rx = pattern;
      rx.lastIndex = 0;
      paths = paths.filter((path) => rx.test(path));
    }
  }
  if (filter)
    paths = paths.filter(filter);
  return paths;
}

export {
  getStatAsync,
  getFingerprintAsync,
  walkSyncAsync,
  filesAsync
};
//# sourceMappingURL=chunk-JPTP6WJC.js.map