import {
  SerialQueue
} from "../../chunk-DXM327S3.js";
import "../../chunk-NLNCD3ES.js";
import "../../chunk-BMLTMNZA.js";
import "../../chunk-7QYVSWCZ.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-5UOZKM4M.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-2DAGZ4FT.js";
import "../../chunk-3MLDC2KV.js";
import "../../chunk-7G6NITL4.js";
import "../../chunk-RSLTBO5X.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-AKLYUMQO.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-3KKFLSLG.js";
import "../../chunk-PLBFBDKH.js";
import "../../chunk-2H4XRKWS.js";
import "../../chunk-WJUQ3VXF.js";
import "../../chunk-O4GTSXBN.js";
import "../../chunk-2OUSR2BE.js";
import "../../chunk-ZDZ4EQHN.js";
import "../../chunk-PZP2B3FC.js";
import "../../chunk-NSJKG6AJ.js";
import "../../chunk-XHPHUZE4.js";
import "../../chunk-NRGUBMFA.js";
import "../../chunk-H564H42Z.js";
import "../../chunk-MLCD7TOL.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-LAWEUL6N.js";
import "../../chunk-V5ZQ2SFQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-EDNCPFSF.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-3KQS63H6.js";
import "../../chunk-C7K2ID3C.js";
import {
  sleep
} from "../../chunk-L324TYGN.js";
import "../../chunk-5DS3NT57.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-UO7L7NBK.js";
import "../../chunk-QUQRUDWG.js";
import "../../chunk-ITJJZ6AV.js";
import "../../chunk-QUKKMPRF.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-X56GIAWQ.js";
import "../../chunk-PN34O4SN.js";
import "../../chunk-UOAPXGA4.js";
import "../../chunk-HJ22ULAI.js";
import "../../chunk-EJGW3W3K.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/exec/queue.spec.ts
describe("queue", () => {
  it("should execute in strict order", async () => {
    expect.assertions(1);
    const list = [];
    const queue = new SerialQueue();
    void queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await sleep(1);
      list.push("c");
    });
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
  });
  it("should execute in random order", async () => {
    expect.assertions(1);
    const list = [];
    void (async () => {
      await sleep(100);
      list.push("a");
    })();
    void (async () => {
      await sleep(200);
      list.push("b");
    })();
    void (async () => {
      await sleep(1);
      list.push("c");
    })();
    await sleep(500);
    expect(list).toEqual(["c", "a", "b"]);
  });
  it("should return value", async () => {
    expect.assertions(2);
    const list = [];
    const queue = new SerialQueue();
    void queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    const r = await queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
      return 123;
    });
    expect(r).toEqual(123);
    expect(list).toEqual(["a", "b"]);
    await queue.wait();
  });
  it("should pause", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new SerialQueue();
    const events = [];
    queue.onAny((...args) => events.push(args));
    void queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await sleep(1);
      list.push("c");
    });
    await queue.pause();
    expect(list).toEqual(["a"]);
    queue.resume();
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didStart",
          1,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didUpdate",
          3,
          1,
        ],
        Array [
          "didUpdate",
          3,
          2,
        ],
        Array [
          "didUpdate",
          3,
          3,
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
  it("should cancel the rest", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new SerialQueue();
    const events = [];
    queue.onAny((...args) => events.push(args));
    await queue.pause();
    void queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await sleep(1);
      list.push("c");
    }).then((r) => {
      expect(r).toBe(void 0);
    });
    await queue.cancelAll();
    queue.resume();
    await queue.wait();
    expect(list).toEqual([]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didCancel",
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
});
//# sourceMappingURL=queue.spec.js.map