"use strict";

var _chunkKMITBP74cjs = require('../../chunk-KMITBP74.cjs');
require('../../chunk-7BMZYEWF.cjs');
require('../../chunk-UKD65B23.cjs');
require('../../chunk-Y6KPVUVD.cjs');
require('../../chunk-J42M6DF3.cjs');
require('../../chunk-ZYPCVNSG.cjs');
require('../../chunk-VFIICDKU.cjs');
require('../../chunk-PDXKNB3S.cjs');
require('../../chunk-XR7AMYN7.cjs');
require('../../chunk-SLEHBFHV.cjs');
require('../../chunk-KMMN6P2X.cjs');
require('../../chunk-AGQV4BOO.cjs');
require('../../chunk-LURLRIHI.cjs');
require('../../chunk-67Q7IWIS.cjs');
require('../../chunk-B4JXPT6I.cjs');
require('../../chunk-KCBJGJ24.cjs');
require('../../chunk-RPAQV2V5.cjs');
require('../../chunk-SVJWXMAG.cjs');
require('../../chunk-RLHQ6YHC.cjs');
require('../../chunk-MPD2DJAD.cjs');
require('../../chunk-ZGKV237Z.cjs');
require('../../chunk-7BEQHGH5.cjs');
require('../../chunk-VAG3XY63.cjs');
require('../../chunk-FEYF6QXS.cjs');
require('../../chunk-SFVQNT7T.cjs');
require('../../chunk-N7OUNPMM.cjs');
require('../../chunk-Z4FNOCPD.cjs');
require('../../chunk-GWXPD6I7.cjs');
require('../../chunk-N5KTMDVO.cjs');
require('../../chunk-B3U4FDQH.cjs');
require('../../chunk-YELWQAMG.cjs');
require('../../chunk-RHWKNEUH.cjs');
require('../../chunk-DRU33ZUG.cjs');
require('../../chunk-LHP7OTMV.cjs');
require('../../chunk-5BF2LEAU.cjs');
require('../../chunk-6T6PI6XG.cjs');
require('../../chunk-TUWUD5A6.cjs');
require('../../chunk-CUGOCLWN.cjs');
require('../../chunk-W3WUDQIC.cjs');
require('../../chunk-BXM45HLQ.cjs');
require('../../chunk-HHZVPIBD.cjs');
require('../../chunk-YY4AHBBL.cjs');
require('../../chunk-IMCDDJAJ.cjs');

// src/common/log/log.spec.ts
describe("logger", () => {
  it("should log different levels", () => {
    const messages = [];
    const logger = _chunkKMITBP74cjs.LoggerContext.call(void 0, );
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    log("Simple");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["Simple"],
        name: "test"
      },
      {
        level: 0,
        messages: ["Hello"],
        name: "test"
      },
      {
        level: 1,
        messages: ["World"],
        name: "test"
      },
      {
        level: 2,
        messages: ["is on"],
        name: "test"
      },
      {
        level: 3,
        messages: ["Fire"],
        name: "test"
      },
      {
        level: 4,
        messages: ["Fatal"],
        name: "test"
      }
    ]);
  });
  it("should log filter level", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = _chunkKMITBP74cjs.LoggerContext.call(void 0, );
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    expect(log.label).toBe("test");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      { name: "test", messages: ["Hello"], level: 0 },
      // xxx
      { name: "test", messages: ["World"], level: 1 },
      { name: "test", messages: ["is on"], level: 2 },
      { name: "test", messages: ["Fire"], level: 3 },
      { name: "test", messages: ["Fatal"], level: 4 }
    ]);
    {
      const log2 = log.extend("ext");
      log2.debug("Hello");
      log2.info("World2");
      log2.warn("is on");
      log2.error("Fire");
      try {
        log2.assert(false, "Fatal");
      } catch (err) {
      }
      expect(messages).toEqual([
        { name: "test", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test", messages: ["World"], level: 1 },
        { name: "test", messages: ["is on"], level: 2 },
        { name: "test", messages: ["Fire"], level: 3 },
        { name: "test", messages: ["Fatal"], level: 4 },
        { name: "test:ext", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test:ext", messages: ["World2"], level: 1 },
        { name: "test:ext", messages: ["is on"], level: 2 },
        { name: "test:ext", messages: ["Fire"], level: 3 },
        { name: "test:ext", messages: ["Fatal"], level: 4 }
      ]);
    }
  });
  it("should log filter namespace", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = _chunkKMITBP74cjs.LoggerContext.call(void 0, );
    logger.setHandlers([LoggerTestHandler]);
    logger.setFilter("a*,-ab");
    const aa = logger("aa");
    const ab = logger("ab");
    const xy = logger("xy");
    aa("aa");
    ab("ab");
    xy("xy");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      }
    ]);
    const xyz = aa.extend("xyz");
    xyz("xyz");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      },
      {
        level: 0,
        messages: ["xyz"],
        name: "aa:xyz"
      }
    ]);
  });
  it("should fake log", () => {
    const messages = [];
    const logger = _chunkKMITBP74cjs.LoggerContext.call(void 0, );
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test", false);
    const { info, error, warn, debug, assert } = log;
    log("Simple");
    debug("Hello");
    info("World");
    warn("is on");
    error("Fire");
    expect(messages).toEqual([]);
  });
});
//# sourceMappingURL=log.spec.cjs.map