import {
  Emitter,
  getGlobalEmitter
} from "../../chunk-NLNCD3ES.js";
import "../../chunk-7QYVSWCZ.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-5UOZKM4M.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-2DAGZ4FT.js";
import "../../chunk-3MLDC2KV.js";
import "../../chunk-7G6NITL4.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-AKLYUMQO.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-3KKFLSLG.js";
import "../../chunk-PLBFBDKH.js";
import "../../chunk-2H4XRKWS.js";
import "../../chunk-WJUQ3VXF.js";
import "../../chunk-O4GTSXBN.js";
import "../../chunk-2OUSR2BE.js";
import "../../chunk-ZDZ4EQHN.js";
import "../../chunk-PZP2B3FC.js";
import "../../chunk-NSJKG6AJ.js";
import "../../chunk-XHPHUZE4.js";
import "../../chunk-NRGUBMFA.js";
import "../../chunk-H564H42Z.js";
import "../../chunk-MLCD7TOL.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-LAWEUL6N.js";
import "../../chunk-V5ZQ2SFQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-EDNCPFSF.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-3KQS63H6.js";
import "../../chunk-C7K2ID3C.js";
import {
  sleep,
  waitOn
} from "../../chunk-L324TYGN.js";
import "../../chunk-5DS3NT57.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-UO7L7NBK.js";
import "../../chunk-QUQRUDWG.js";
import "../../chunk-ITJJZ6AV.js";
import {
  getSecureRandomIfPossible
} from "../../chunk-QUKKMPRF.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-X56GIAWQ.js";
import "../../chunk-PN34O4SN.js";
import "../../chunk-UOAPXGA4.js";
import "../../chunk-HJ22ULAI.js";
import "../../chunk-EJGW3W3K.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/msg/emitter.spec.ts
import { vi } from "vitest";
function lazyListener(emitter, listenerKey) {
  const name = Math.round(getSecureRandomIfPossible() * 100);
  const events = [];
  let lazyResolve;
  const incoming = (key, obj) => {
    const ev = { key, obj };
    events.push(ev);
    lazyResolve && lazyResolve();
  };
  if (listenerKey) {
    if (emitter.on) {
      emitter.on(listenerKey, (obj) => {
        incoming(listenerKey, obj);
      });
    } else if (emitter.addEventListener) {
      emitter.addEventListener(listenerKey, (obj) => {
        incoming(listenerKey, obj);
      });
    } else {
      emitter.log.error(name, "Cannot listen to key");
    }
  } else {
    if (emitter.onAny) {
      emitter.onAny((key, obj) => {
        incoming(key, obj);
      });
    } else {
      emitter.log.error(name, "cannot listen to all for", emitter);
    }
  }
  const on = (key, skipUnmatched = true) => {
    return new Promise((resolve, reject) => {
      if (!key) {
        key = listenerKey;
        if (!key) {
          if (events.length) {
            key = events[0].key;
          }
        }
      }
      lazyResolve = () => {
        while (events.length > 0) {
          const ev = events.shift();
          if (ev.key === key) {
            lazyResolve = void 0;
            resolve(ev.obj);
          } else {
            if (skipUnmatched) {
              continue;
            }
            reject(new Error(`Expected ${key}, but found ${ev.key} with value=${ev.obj}`));
          }
          break;
        }
      };
      lazyResolve();
    });
  };
  return on;
}
describe("emitter", () => {
  it("should emit", async () => {
    expect.assertions(4);
    let ctr = 0;
    const e = new Emitter();
    e.on("test", (x, y) => expect(x + y).toBe(123));
    e.on("long", async () => {
      await sleep(500);
      ctr++;
    });
    const ee = e.call;
    await ee.long();
    expect(ctr).toBe(1);
    e.onCall({
      test(x, y) {
        expect(x + y).toBe(123);
      }
    });
    await e.emit("long");
    expect(ctr).toBe(2);
    await e.emit("test", 100, 23);
  });
  it("should work", async () => {
    const e1 = new Emitter();
    const e2 = new Emitter();
    let counter = 99;
    e1.on("a", () => counter++);
    e2.on("a", () => counter--);
    e2.on("b", () => counter--);
    void e1.emit("a");
    expect(counter).toBe(100);
    void e2.emit("a");
    void e2.emit("b");
    expect(counter).toBe(98);
    e1.on("a", () => counter++);
    void e1.emit("a");
    expect(counter).toBe(100);
    e1.removeAllListeners();
    void e1.emit("a");
    expect(counter).toBe(100);
  });
  it("should wait on", async () => {
    expect.assertions(2);
    const e1 = new Emitter();
    setTimeout(() => {
      void e1.emit("f", 1);
    }, 100);
    const v = await waitOn(e1, "f");
    expect(v).toBe(1);
    await expect(waitOn(e1, "x", 10)).rejects.toThrow(
      "Did not response in time"
    );
  });
  it("should wait on integrated", async () => {
    expect.assertions(2);
    const e1 = new Emitter();
    queueMicrotask(() => {
      void e1.emit("f", 1);
    });
    const v = await e1.waitOn("f", 100);
    expect(v).toBe(1);
    await expect(e1.waitOn("x", 10)).rejects.toThrow(
      "Did not respond in time"
    );
  });
  it("should work lazy", async () => {
    const e1 = new Emitter();
    const e2 = new Emitter();
    const on1 = lazyListener(e1);
    const on2 = lazyListener(e2);
    await e1.emit("a", 1);
    await e1.emit("b", 2);
    await e2.emit("a", 3);
    expect(await on2("a")).toBe(3);
    expect(await on1("b")).toBe(2);
  });
  it("should expect events", async () => {
    expect.assertions(3);
    const e = new Emitter();
    e.on("a", (v) => expect(v).toBe(1));
    e.on("a", (v) => expect(v).toBe(1));
    e.on("b", (v) => expect(v).toBe(1));
    await e.emit("a", 1);
    await e.emit("b", 1);
  });
  it("should expect once", async () => {
    expect.assertions(1);
    const e = new Emitter();
    e.once("a", (v) => expect(v).toBe(1));
    void e.emit("a", 1);
    void e.emit("a", 2);
    void e.emit("a", 3);
  });
  it("should mock events", async () => {
    const fn = vi.fn();
    const e = new Emitter();
    e.on("a", fn);
    e.on("a", fn);
    e.on("b", fn);
    await e.emit("a", 1);
    await e.emit("b", 1);
    expect(fn).toBeCalledTimes(3);
  });
  it("should work with global listener", async () => {
    const fn = vi.fn();
    const e = getGlobalEmitter();
    e.on("a", fn);
    e.on("a", fn);
    e.on("b", fn);
    await e.emit("a", 1);
    await getGlobalEmitter().emit("b", 2);
    expect(fn).toBeCalledTimes(3);
  });
  it("should respect priorities", async () => {
    const e = new Emitter();
    const l = [];
    e.on("p", () => l.push(2), { priority: 100 });
    e.on("p", () => l.push(5), { priority: -1 });
    e.on("p", () => l.push(6), { priority: -2 });
    e.on("p", () => l.push(1), { priority: 110 });
    e.on("p", () => l.push(3));
    e.on("p", () => l.push(4));
    await e.emit("p");
    expect(l).toEqual([1, 2, 3, 4, 5, 6]);
  });
  it("should resolve when the event is emitted", async () => {
    const emitter = new Emitter();
    const eventName = "testEvent";
    const eventValue = "Hello, World!";
    const promise = emitter.waitOn(eventName);
    setTimeout(() => {
      emitter.emit(eventName, eventValue);
    }, 100);
    await expect(promise).resolves.toBe(eventValue);
  });
  it("should reject when the timeout is reached", async () => {
    const emitter = new Emitter();
    const eventName = "testEvent";
    const promise = emitter.waitOn(eventName, 100);
    await expect(promise).rejects.toThrow("Did not respond in time");
  });
});
//# sourceMappingURL=emitter.spec.js.map