import {
  decodeJson,
  encodeJson
} from "../../chunk-SPKWNIPO.js";
import "../../chunk-DVBRAJ3X.js";
import "../../chunk-VK3HQ7U6.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-M6NJWFDP.js";
import {
  useRPC,
  useRPCHub
} from "../../chunk-WZDTE5W3.js";
import {
  createLocalChannelPair
} from "../../chunk-CYDFP47V.js";
import "../../chunk-URTIMVUU.js";
import "../../chunk-NLNCD3ES.js";
import "../../chunk-BMLTMNZA.js";
import "../../chunk-7QYVSWCZ.js";
import "../../chunk-VI7IQ5ZG.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-5UOZKM4M.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-2DAGZ4FT.js";
import "../../chunk-3MLDC2KV.js";
import "../../chunk-7G6NITL4.js";
import "../../chunk-RSLTBO5X.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-AKLYUMQO.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-3KKFLSLG.js";
import "../../chunk-PLBFBDKH.js";
import {
  useStringHashPool
} from "../../chunk-2H4XRKWS.js";
import "../../chunk-WJUQ3VXF.js";
import "../../chunk-O4GTSXBN.js";
import "../../chunk-2OUSR2BE.js";
import "../../chunk-ZDZ4EQHN.js";
import "../../chunk-PZP2B3FC.js";
import "../../chunk-NSJKG6AJ.js";
import "../../chunk-XHPHUZE4.js";
import "../../chunk-NRGUBMFA.js";
import "../../chunk-H564H42Z.js";
import "../../chunk-MLCD7TOL.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-LAWEUL6N.js";
import "../../chunk-V5ZQ2SFQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-EDNCPFSF.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-3KQS63H6.js";
import "../../chunk-C7K2ID3C.js";
import {
  sleep
} from "../../chunk-L324TYGN.js";
import "../../chunk-5DS3NT57.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-UO7L7NBK.js";
import "../../chunk-QUQRUDWG.js";
import "../../chunk-ITJJZ6AV.js";
import "../../chunk-QUKKMPRF.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-X56GIAWQ.js";
import "../../chunk-PN34O4SN.js";
import {
  cloneObject
} from "../../chunk-UOAPXGA4.js";
import "../../chunk-HJ22ULAI.js";
import "../../chunk-EJGW3W3K.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/msg/rpc.spec.ts
var bobCount = 0;
var Bob = {
  hi(name) {
    return `Hi ${name}, I am Bob`;
  },
  bump() {
    bobCount += 1;
  },
  getCount() {
    return bobCount;
  }
};
var Alice = {
  hello(name) {
    return `Hello ${name}, my name is Alice`;
  }
};
describe("rpc async", () => {
  beforeEach(() => {
    bobCount = 0;
  });
  it("basic", async () => {
    const log = [];
    const [c1, c2] = createLocalChannelPair();
    const serialize = (data) => {
      log.push(cloneObject(data));
      return encodeJson(data);
    };
    const deserialize = (data) => decodeJson(data);
    const bob = useRPC(Bob, {
      post: (data) => c1.postMessage(data),
      on: (data) => c1.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => c2.postMessage(data),
      on: (data) => c2.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(void alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    c1.close();
    c2.close();
    expect(log).toMatchInlineSnapshot(`
      Array [
        Array [
          1,
          1,
          1335831723,
          "Bob",
        ],
        Array [
          3,
          1,
          "Hello Bob, my name is Alice",
        ],
        Array [
          1,
          2,
          1748694682,
          "Alice",
        ],
        Array [
          3,
          2,
          "Hi Alice, I am Bob",
        ],
        Array [
          2,
          1648103349,
        ],
      ]
    `);
  });
  it("hub", async () => {
    const [c1, c2] = createLocalChannelPair();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bobHub = useRPCHub({
      post: (data) => c1.postMessage(data),
      on: (data) => c1.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    const bob = bobHub(Bob);
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => c2.postMessage(data),
      on: (data) => c2.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(void alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    c1.close();
    c2.close();
  });
  it("timeout async", async (done) => {
    const [f1, f2] = createLocalChannelPair();
    const rpc1 = useRPC({
      async echo(v, s = 5) {
        await sleep(s);
        return `${v}_1`;
      }
    }, {
      post: (data) => {
        f1.postMessage(data);
      },
      on: (data) => f1.on("message", (msg) => {
        void data(msg.data);
      }),
      timeout: 10
    });
    const rpc2 = useRPC({
      async echo(v, s = 5) {
        await sleep(s);
        return `${v}_2`;
      }
    }, {
      post: (data) => {
        f2.postMessage(data);
      },
      on: (data) => f2.on("message", (msg) => {
        void data(msg.data);
      }),
      timeout: 10
    });
    const r = await rpc1.echo("abc");
    expect(r).toMatchInlineSnapshot(`"abc_2"`);
    try {
      const r2 = await rpc1.echo("abc", 50);
      expect(false).toBe(true);
    } catch (err) {
      expect(err).toMatchInlineSnapshot(`[Error: rpc timeout on calling "echo"]`);
    }
  });
  it("async", async (done) => {
    function echo(n) {
      return n;
    }
    async function echoAsync(n) {
      return n;
    }
    expect(await echo(1)).toBe(1);
    expect(await echoAsync(2)).toBe(2);
  });
});
//# sourceMappingURL=rpc.spec.js.map